<?php

namespace Biljnasinergija.rs\Proba\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Biljnasinergija.rs\Proba\Http\Requests\PEXIMAdminRequest;
use Biljnasinergija.rs\Proba\Interfaces\PEXIMRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class PEXIMAdminController extends AdminController
{
    /**
     * Initialize p_e_x_i_m controller.
     *
     * @param type PEXIMRepositoryInterface $p_e_x_i_m
     *
     * @return type
     */
    public function __construct(PEXIMRepositoryInterface $p_e_x_i_m)
    {
        $this->model = $p_e_x_i_m;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(PEXIMAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('proba.p_e_x_i_m.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('proba::p_e_x_i_m.names').' :: ');

        return $this->theme->of('proba::admin.p_e_x_i_m.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(PEXIMAdminRequest $request, $id)
    {
        $p_e_x_i_m = $this->model->find($id);

        if (empty($p_e_x_i_m)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('proba::admin.p_e_x_i_m.new');
        }

        if ($request->wantsJson()) {
            return $p_e_x_i_m;
        }

        Former::populate($p_e_x_i_m);

        return view('proba::admin.p_e_x_i_m.show', compact('p_e_x_i_m'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PEXIMAdminRequest $request)
    {
        $p_e_x_i_m = $this->model->findOrNew(0);
        Former::populate($p_e_x_i_m);

        return view('proba::admin.p_e_x_i_m.create', compact('p_e_x_i_m'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PEXIMAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $p_e_x_i_m = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('proba::p_e_x_i_m.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(PEXIMAdminRequest $request, $id)
    {
        $p_e_x_i_m = $this->model->find($id);

        Former::populate($p_e_x_i_m);

        return view('proba::admin.p_e_x_i_m.edit', compact('p_e_x_i_m'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(PEXIMAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $p_e_x_i_m = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('proba::p_e_x_i_m.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(PEXIMAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('proba::p_e_x_i_m.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
